@@ -2,6 +2,8 @@
 
 from __future__ import print_function
 
+import pytest
+
 from datetime import datetime, timedelta
 import itertools
 
@@ -15,8 +17,7 @@ import pandas as pd
 
 from pandas.util.testing import (assert_almost_equal,
                                  assert_series_equal,
-                                 assert_frame_equal,
-                                 assertRaisesRegexp)
+                                 assert_frame_equal)
 
 import pandas.util.testing as tm
 
@@ -27,9 +28,7 @@ from pandas.tests.frame.common import TestData
 # structure
 
 
-class TestDataFrameBlockInternals(tm.TestCase, TestData):
-
-    _multiprocess_can_split_ = True
+class TestDataFrameBlockInternals(TestData):
 
     def test_cast_internals(self):
         casted = DataFrame(self.frame._data, dtype=int)
@@ -42,18 +41,24 @@ class TestDataFrameBlockInternals(tm.TestCase, TestData):
 
     def test_consolidate(self):
         self.frame['E'] = 7.
-        consolidated = self.frame.consolidate()
-        self.assertEqual(len(consolidated._data.blocks), 1)
+        consolidated = self.frame._consolidate()
+        assert len(consolidated._data.blocks) == 1
 
         # Ensure copy, do I want this?
-        recons = consolidated.consolidate()
-        self.assertIsNot(recons, consolidated)
-        assert_frame_equal(recons, consolidated)
+        recons = consolidated._consolidate()
+        assert recons is not consolidated
+        tm.assert_frame_equal(recons, consolidated)
 
         self.frame['F'] = 8.
-        self.assertEqual(len(self.frame._data.blocks), 3)
-        self.frame.consolidate(inplace=True)
-        self.assertEqual(len(self.frame._data.blocks), 1)
+        assert len(self.frame._data.blocks) == 3
+
+        self.frame._consolidate(inplace=True)
+        assert len(self.frame._data.blocks) == 1
+
+    def test_consolidate_deprecation(self):
+        self.frame['E'] = 7
+        with tm.assert_produces_warning(FutureWarning):
+            self.frame.consolidate()
 
     def test_consolidate_inplace(self):
         frame = self.frame.copy()  # noqa
@@ -64,18 +69,18 @@ class TestDataFrameBlockInternals(tm.TestCase, TestData):
 
     def test_as_matrix_consolidate(self):
         self.frame['E'] = 7.
-        self.assertFalse(self.frame._data.is_consolidated())
+        assert not self.frame._data.is_consolidated()
         _ = self.frame.as_matrix()  # noqa
-        self.assertTrue(self.frame._data.is_consolidated())
+        assert self.frame._data.is_consolidated()
 
     def test_modify_values(self):
         self.frame.values[5] = 5
-        self.assertTrue((self.frame.values[5] == 5).all())
+        assert (self.frame.values[5] == 5).all()
 
         # unconsolidated
         self.frame['E'] = 7.
         self.frame.values[6] = 6
-        self.assertTrue((self.frame.values[6] == 6).all())
+        assert (self.frame.values[6] == 6).all()
 
     def test_boolean_set_uncons(self):
         self.frame['E'] = 7.
@@ -90,41 +95,47 @@ class TestDataFrameBlockInternals(tm.TestCase, TestData):
         self.frame['foo'] = 'bar'
 
         values = self.frame.as_matrix(['A', 'B', 'C', 'D'])
-        self.assertEqual(values.dtype, np.float64)
+        assert values.dtype == np.float64
 
     def test_as_matrix_lcd(self):
 
         # mixed lcd
         values = self.mixed_float.as_matrix(['A', 'B', 'C', 'D'])
-        self.assertEqual(values.dtype, np.float64)
+        assert values.dtype == np.float64
 
         values = self.mixed_float.as_matrix(['A', 'B', 'C'])
-        self.assertEqual(values.dtype, np.float32)
+        assert values.dtype == np.float32
 
         values = self.mixed_float.as_matrix(['C'])
-        self.assertEqual(values.dtype, np.float16)
+        assert values.dtype == np.float16
 
+        # GH 10364
+        # B uint64 forces float because there are other signed int types
         values = self.mixed_int.as_matrix(['A', 'B', 'C', 'D'])
-        self.assertEqual(values.dtype, np.int64)
+        assert values.dtype == np.float64
 
         values = self.mixed_int.as_matrix(['A', 'D'])
-        self.assertEqual(values.dtype, np.int64)
+        assert values.dtype == np.int64
 
-        # guess all ints are cast to uints....
+        # B uint64 forces float because there are other signed int types
         values = self.mixed_int.as_matrix(['A', 'B', 'C'])
-        self.assertEqual(values.dtype, np.int64)
+        assert values.dtype == np.float64
+
+        # as B and C are both unsigned, no forcing to float is needed
+        values = self.mixed_int.as_matrix(['B', 'C'])
+        assert values.dtype == np.uint64
 
         values = self.mixed_int.as_matrix(['A', 'C'])
-        self.assertEqual(values.dtype, np.int32)
+        assert values.dtype == np.int32
 
         values = self.mixed_int.as_matrix(['C', 'D'])
-        self.assertEqual(values.dtype, np.int64)
+        assert values.dtype == np.int64
 
         values = self.mixed_int.as_matrix(['A'])
-        self.assertEqual(values.dtype, np.int32)
+        assert values.dtype == np.int32
 
         values = self.mixed_int.as_matrix(['C'])
-        self.assertEqual(values.dtype, np.uint8)
+        assert values.dtype == np.uint8
 
     def test_constructor_with_convert(self):
         # this is actually mostly a test of lib.maybe_convert_objects
@@ -136,7 +147,7 @@ class TestDataFrameBlockInternals(tm.TestCase, TestData):
 
         df = DataFrame({'A': [2 ** 63]})
         result = df['A']
-        expected = Series(np.asarray([2 ** 63], np.object_), name='A')
+        expected = Series(np.asarray([2 ** 63], np.uint64), name='A')
         assert_series_equal(result, expected)
 
         df = DataFrame({'A': [datetime(2005, 1, 1), True]})
@@ -209,8 +220,8 @@ class TestDataFrameBlockInternals(tm.TestCase, TestData):
         # mixed-type frames
         self.mixed_frame['datetime'] = datetime.now()
         self.mixed_frame['timedelta'] = timedelta(days=1, seconds=1)
-        self.assertEqual(self.mixed_frame['datetime'].dtype, 'M8[ns]')
-        self.assertEqual(self.mixed_frame['timedelta'].dtype, 'm8[ns]')
+        assert self.mixed_frame['datetime'].dtype == 'M8[ns]'
+        assert self.mixed_frame['timedelta'].dtype == 'm8[ns]'
         result = self.mixed_frame.get_dtype_counts().sort_values()
         expected = Series({'float64': 4,
                            'object': 1,
@@ -275,10 +286,10 @@ class TestDataFrameBlockInternals(tm.TestCase, TestData):
                              columns=["A", "B", "C"],
                              dtype=dtype)
 
-        self.assertRaises(NotImplementedError, f,
-                          [("A", "datetime64[h]"),
-                           ("B", "str"),
-                           ("C", "int32")])
+        pytest.raises(NotImplementedError, f,
+                      [("A", "datetime64[h]"),
+                       ("B", "str"),
+                       ("C", "int32")])
 
         # these work (though results may be unexpected)
         f('int64')
@@ -296,12 +307,12 @@ class TestDataFrameBlockInternals(tm.TestCase, TestData):
         df1 = df0.reset_index()[["A", "B", "C"]]
         # this assert verifies that the above operations have
         # induced a block rearrangement
-        self.assertTrue(df0._data.blocks[0].dtype !=
-                        df1._data.blocks[0].dtype)
+        assert (df0._data.blocks[0].dtype != df1._data.blocks[0].dtype)
+
         # do the real tests
         assert_frame_equal(df0, df1)
-        self.assertTrue(df0.equals(df1))
-        self.assertTrue(df1.equals(df0))
+        assert df0.equals(df1)
+        assert df1.equals(df0)
 
     def test_copy_blocks(self):
         # API/ENH 9607
@@ -309,13 +320,17 @@ class TestDataFrameBlockInternals(tm.TestCase, TestData):
         column = df.columns[0]
 
         # use the default copy=True, change a column
-        blocks = df.as_blocks()
+
+        # deprecated 0.21.0
+        with tm.assert_produces_warning(FutureWarning,
+                                        check_stacklevel=False):
+            blocks = df.as_blocks()
         for dtype, _df in blocks.items():
             if column in _df:
-                _df.ix[:, column] = _df[column] + 1
+                _df.loc[:, column] = _df[column] + 1
 
         # make sure we did not change the original DataFrame
-        self.assertFalse(_df[column].equals(df[column]))
+        assert not _df[column].equals(df[column])
 
     def test_no_copy_blocks(self):
         # API/ENH 9607
@@ -323,36 +338,40 @@ class TestDataFrameBlockInternals(tm.TestCase, TestData):
         column = df.columns[0]
 
         # use the copy=False, change a column
-        blocks = df.as_blocks(copy=False)
+
+        # deprecated 0.21.0
+        with tm.assert_produces_warning(FutureWarning,
+                                        check_stacklevel=False):
+            blocks = df.as_blocks(copy=False)
         for dtype, _df in blocks.items():
             if column in _df:
-                _df.ix[:, column] = _df[column] + 1
+                _df.loc[:, column] = _df[column] + 1
 
         # make sure we did change the original DataFrame
-        self.assertTrue(_df[column].equals(df[column]))
+        assert _df[column].equals(df[column])
 
     def test_copy(self):
         cop = self.frame.copy()
         cop['E'] = cop['A']
-        self.assertNotIn('E', self.frame)
+        assert 'E' not in self.frame
 
         # copy objects
         copy = self.mixed_frame.copy()
-        self.assertIsNot(copy._data, self.mixed_frame._data)
+        assert copy._data is not self.mixed_frame._data
 
     def test_pickle(self):
-        unpickled = self.round_trip_pickle(self.mixed_frame)
+        unpickled = tm.round_trip_pickle(self.mixed_frame)
         assert_frame_equal(self.mixed_frame, unpickled)
 
         # buglet
         self.mixed_frame._data.ndim
 
         # empty
-        unpickled = self.round_trip_pickle(self.empty)
+        unpickled = tm.round_trip_pickle(self.empty)
         repr(unpickled)
 
         # tz frame
-        unpickled = self.round_trip_pickle(self.tzframe)
+        unpickled = tm.round_trip_pickle(self.tzframe)
         assert_frame_equal(self.tzframe, unpickled)
 
     def test_consolidate_datetime64(self):
@@ -372,11 +391,13 @@ starting,ending,measure
         ser_starting.index = ser_starting.values
         ser_starting = ser_starting.tz_localize('US/Eastern')
         ser_starting = ser_starting.tz_convert('UTC')
+        ser_starting.index.name = 'starting'
 
         ser_ending = df.ending
         ser_ending.index = ser_ending.values
         ser_ending = ser_ending.tz_localize('US/Eastern')
         ser_ending = ser_ending.tz_convert('UTC')
+        ser_ending.index.name = 'ending'
 
         df.starting = ser_starting.index
         df.ending = ser_ending.index
@@ -386,8 +407,8 @@ starting,ending,measure
         tm.assert_index_equal(pd.DatetimeIndex(df.ending), ser_ending.index)
 
     def test_is_mixed_type(self):
-        self.assertFalse(self.frame._is_mixed_type)
-        self.assertTrue(self.mixed_frame._is_mixed_type)
+        assert not self.frame._is_mixed_type
+        assert self.mixed_frame._is_mixed_type
 
     def test_get_numeric_data(self):
         # TODO(wesm): unused?
@@ -415,12 +436,12 @@ starting,ending,measure
                        index=np.arange(10))
 
         result = df._get_numeric_data()
-        expected = df.ix[:, ['a', 'b', 'd', 'e', 'f']]
+        expected = df.loc[:, ['a', 'b', 'd', 'e', 'f']]
         assert_frame_equal(result, expected)
 
-        only_obj = df.ix[:, ['c', 'g']]
+        only_obj = df.loc[:, ['c', 'g']]
         result = only_obj._get_numeric_data()
-        expected = df.ix[:, []]
+        expected = df.loc[:, []]
         assert_frame_equal(result, expected)
 
         df = DataFrame.from_dict(
@@ -439,7 +460,7 @@ starting,ending,measure
         oops = self.mixed_frame.T.T
         converted = oops._convert(datetime=True)
         assert_frame_equal(converted, self.mixed_frame)
-        self.assertEqual(converted['A'].dtype, np.float64)
+        assert converted['A'].dtype == np.float64
 
         # force numeric conversion
         self.mixed_frame['H'] = '1.'
@@ -449,25 +470,25 @@ starting,ending,measure
         l = len(self.mixed_frame)
         self.mixed_frame['J'] = '1.'
         self.mixed_frame['K'] = '1'
-        self.mixed_frame.ix[0:5, ['J', 'K']] = 'garbled'
+        self.mixed_frame.loc[0:5, ['J', 'K']] = 'garbled'
         converted = self.mixed_frame._convert(datetime=True, numeric=True)
-        self.assertEqual(converted['H'].dtype, 'float64')
-        self.assertEqual(converted['I'].dtype, 'int64')
-        self.assertEqual(converted['J'].dtype, 'float64')
-        self.assertEqual(converted['K'].dtype, 'float64')
-        self.assertEqual(len(converted['J'].dropna()), l - 5)
-        self.assertEqual(len(converted['K'].dropna()), l - 5)
+        assert converted['H'].dtype == 'float64'
+        assert converted['I'].dtype == 'int64'
+        assert converted['J'].dtype == 'float64'
+        assert converted['K'].dtype == 'float64'
+        assert len(converted['J'].dropna()) == l - 5
+        assert len(converted['K'].dropna()) == l - 5
 
         # via astype
         converted = self.mixed_frame.copy()
         converted['H'] = converted['H'].astype('float64')
         converted['I'] = converted['I'].astype('int64')
-        self.assertEqual(converted['H'].dtype, 'float64')
-        self.assertEqual(converted['I'].dtype, 'int64')
+        assert converted['H'].dtype == 'float64'
+        assert converted['I'].dtype == 'int64'
 
         # via astype, but errors
         converted = self.mixed_frame.copy()
-        with assertRaisesRegexp(ValueError, 'invalid literal'):
+        with tm.assert_raises_regex(ValueError, 'invalid literal'):
             converted['H'].astype('int32')
 
         # mixed in a single column
@@ -482,6 +503,32 @@ starting,ending,measure
         mixed2 = mixed1._convert(datetime=True)
         assert_frame_equal(mixed1, mixed2)
 
+    def test_infer_objects(self):
+        # GH 11221
+        df = DataFrame({'a': ['a', 1, 2, 3],
+                        'b': ['b', 2.0, 3.0, 4.1],
+                        'c': ['c', datetime(2016, 1, 1),
+                              datetime(2016, 1, 2),
+                              datetime(2016, 1, 3)],
+                        'd': [1, 2, 3, 'd']},
+                       columns=['a', 'b', 'c', 'd'])
+        df = df.iloc[1:].infer_objects()
+
+        assert df['a'].dtype == 'int64'
+        assert df['b'].dtype == 'float64'
+        assert df['c'].dtype == 'M8[ns]'
+        assert df['d'].dtype == 'object'
+
+        expected = DataFrame({'a': [1, 2, 3],
+                              'b': [2.0, 3.0, 4.1],
+                              'c': [datetime(2016, 1, 1),
+                                    datetime(2016, 1, 2),
+                                    datetime(2016, 1, 3)],
+                              'd': [2, 3, 'd']},
+                             columns=['a', 'b', 'c', 'd'])
+        # reconstruct frame to verify inference is same
+        tm.assert_frame_equal(df.reset_index(drop=True), expected)
+
     def test_stale_cached_series_bug_473(self):
 
         # this is chained, but ok
@@ -494,7 +541,7 @@ starting,ending,measure
             repr(Y)
             result = Y.sum()  # noqa
             exp = Y['g'].sum()  # noqa
-            self.assertTrue(pd.isnull(Y['g']['c']))
+            assert pd.isna(Y['g']['c'])
 
     def test_get_X_columns(self):
         # numeric and object columns
@@ -505,8 +552,8 @@ starting,ending,measure
                         'd': [None, None, None],
                         'e': [3.14, 0.577, 2.773]})
 
-        self.assert_numpy_array_equal(df._get_numeric_data().columns,
-                                      ['a', 'b', 'e'])
+        tm.assert_index_equal(df._get_numeric_data().columns,
+                              pd.Index(['a', 'b', 'e']))
 
     def test_strange_column_corruption_issue(self):
         # (wesm) Unclear how exactly this is related to internal matters
@@ -527,6 +574,6 @@ starting,ending,measure
 
         myid = 100
 
-        first = len(df.ix[pd.isnull(df[myid]), [myid]])
-        second = len(df.ix[pd.isnull(df[myid]), [myid]])
-        self.assertTrue(first == second == 0)
+        first = len(df.loc[pd.isna(df[myid]), [myid]])
+        second = len(df.loc[pd.isna(df[myid]), [myid]])
+        assert first == second == 0
